namespace-browser: Service Signature Compatibility Update

- Adapated Signature now reveals more information.
  + argument type information (inArgs only, not outArgs)
  + doc strings (shown in core-tooltip) for methods and interfaces
- Polymer tweaking
  + label attribute was removed on paper-button
  + core-tooltip's internal overlay has .core-tooltip as its class
- Mercury tweaking
  + span was added around various text nodes.
    For some reason, mercury is not diffing them properly.

Screenshots:
* https://screenshot.googleplex.com/UEPot1EF9t
* https://screenshot.googleplex.com/ft28NTLWZX

Change-Id: I92bc8c40830fd9842d4e1ba2012200eba1ff6ab3
diff --git a/src/services/namespace/signature-adapter.js b/src/services/namespace/signature-adapter.js
index d1f364f..e99f351 100644
--- a/src/services/namespace/signature-adapter.js
+++ b/src/services/namespace/signature-adapter.js
@@ -2,15 +2,18 @@
 
 module.exports = adapt;
 /*
  * Adapts from IPC service Signatures to a custom signature struct specific
  * to this application.
  * TODO(aghasssemi) Consider separate signature instead of merging?
  */
 function adapt(signatures) {
   var adaptedSig = new Map();
-
+  adaptedSig.pkgNameDescriptions = [];
   signatures.forEach(function(sig) {
-    sig.methods.forEach( function(method) {
+    if (sig.name) {
+      adaptedSig.pkgNameDescriptions[sig.pkgPath + '.' + sig.name] = sig.doc;
+    }
+    sig.methods.forEach(function(method) {
       var key = vom.MiscUtil.uncapitalize(method.name);
       adaptedSig.set(key, method);
     });
@@ -2,15 +2,18 @@
 module.exports = adapt;
 /*
- * Adapts from IPC service Signatures to a custom signature struct specific
- * to this application.
- * TODO(aghasssemi) Consider separate signature instead of merging?
+ * Adapts from IPC service Signatures to a custom signature Map-specific
+ * to this application. Service methods, pkgName, and descriptions are added.
+ * TODO(aghasssemi): Consider separate signature instead of merging?
  */
 function adapt(signatures) {